summaryrefslogtreecommitdiffstats
path: root/kivio/kiviopart/kiviosdk/kivio_shape_data.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kivio/kiviopart/kiviosdk/kivio_shape_data.cpp')
-rw-r--r--kivio/kiviopart/kiviosdk/kivio_shape_data.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/kivio/kiviopart/kiviosdk/kivio_shape_data.cpp b/kivio/kiviopart/kiviosdk/kivio_shape_data.cpp
index 431d7987..5305fe13 100644
--- a/kivio/kiviopart/kiviosdk/kivio_shape_data.cpp
+++ b/kivio/kiviopart/kiviosdk/kivio_shape_data.cpp
@@ -27,7 +27,7 @@
#include <kdebug.h>
/*
* Struct for holding information about a shape type
*/
struct KivioShapeTypeInfo
{
@@ -36,10 +36,10 @@ struct KivioShapeTypeInfo
};
/*
* Array of shape info used for loading/saving.
*/
static const int numShapeInfo = 12;
-static struct KivioShapeTypeInfo shapeInfo[] = {
+static struct KivioShapeTypeInfo tqshapeInfo[] = {
{ "Arc", KivioShapeData::kstArc },
{ "Pie", KivioShapeData::kstPie },
{ "LineArray", KivioShapeData::kstLineArray },
@@ -84,7 +84,7 @@ KivioShapeData::KivioShapeData()
m_pLineStyle = new KivioLineStyle();
// m_fgColor = TQColor( 0, 0, 0 );
- m_shapeType = kstNone;
+ m_tqshapeType = kstNone;
m_name = "";
// m_lineWidth = 1.0f;
@@ -119,7 +119,7 @@ KivioShapeData::KivioShapeData( const KivioShapeData &source )
//m_fgColor = source.m_fgColor;
// Copy the rest
- m_shapeType = source.m_shapeType;
+ m_tqshapeType = source.m_tqshapeType;
m_name = TQString(source.m_name);
//m_lineWidth = source.m_lineWidth;
@@ -127,8 +127,8 @@ KivioShapeData::KivioShapeData( const KivioShapeData &source )
source.m_position.copyInto( &m_position );
source.m_dimensions.copyInto( &m_dimensions );
- // If this is a text shape, allocate a text data struct and copy the info
- if( m_shapeType == kstTextBox )
+ // If this is a text tqshape, allocate a text data struct and copy the info
+ if( m_tqshapeType == kstTextBox )
{
m_pTextData = new KivioTextStyle();
@@ -208,7 +208,7 @@ void KivioShapeData::copyInto( KivioShapeData *pTarget ) const
//pTarget->m_fgColor = m_fgColor;
// Copy the rest
- pTarget->m_shapeType = m_shapeType;
+ pTarget->m_tqshapeType = m_tqshapeType;
pTarget->m_name = TQString(m_name);
//pTarget->m_lineWidth = m_lineWidth;
@@ -217,7 +217,7 @@ void KivioShapeData::copyInto( KivioShapeData *pTarget ) const
// If this is a textbox, allocate & copy
- if( m_shapeType == kstTextBox )
+ if( m_tqshapeType == kstTextBox )
{
if( !pTarget->m_pTextData )
{
@@ -283,7 +283,7 @@ bool KivioShapeData::loadXML( const TQDomElement &e )
{
// First make sure we are a text box
- if( m_shapeType == kstTextBox )
+ if( m_tqshapeType == kstTextBox )
{
// If we don't have text data, allocate it
if( !m_pTextData )
@@ -291,12 +291,12 @@ bool KivioShapeData::loadXML( const TQDomElement &e )
m_pTextData->loadXML( ele );
- } // end if m_shapeType==kstTextBox
+ } // end if m_tqshapeType==kstTextBox
}
else if( nodeName == "KivioText" )
{
// First make sure we are a text box
- if( m_shapeType == kstTextBox )
+ if( m_tqshapeType == kstTextBox )
{
KivioTextShapeData *pData = new KivioTextShapeData;
@@ -338,7 +338,7 @@ bool KivioShapeData::loadXML( const TQDomElement &e )
m_pTextData->setFont( pData->m_textFont );
m_pTextData->setColor( pData->m_textColor );
- } // end if m_shapeType==kstTextBox
+ } // end if m_tqshapeType==kstTextBox
else
{
kdDebug(43000) << "KivioShapeData::loadXML() - Loading KivioText, but this is not a textbox!" << endl;
@@ -385,7 +385,7 @@ TQDomElement KivioShapeData::saveXML( TQDomDocument &doc )
// Save if we are a text box etc...
- if( m_shapeType == kstTextBox )
+ if( m_tqshapeType == kstTextBox )
{
if( m_pTextData )
{
@@ -420,21 +420,21 @@ TQDomElement KivioShapeData::saveXML( TQDomDocument &doc )
// The BGFillStyle
e.appendChild( m_pFillStyle->saveXML( doc ) );
// Shape type & name are stored in the shape node
//XmlWriteInt( e, "shapeType", m_shapeType );
//XmlWriteString( e, "name", m_name );
return e;
}
-KivioShapeData::KivioShapeType KivioShapeData::shapeTypeFromString( const TQString &str )
+KivioShapeData::KivioShapeType KivioShapeData::tqshapeTypeFromString( const TQString &str )
{
for( int i=0; i<numShapeInfo; i++ )
{
- if( str.compare( shapeInfo[i].name )==0 )
- return shapeInfo[i].type;
+ if( str.compare( tqshapeInfo[i].name )==0 )
+ return tqshapeInfo[i].type;
}
return kstNone;
@@ -442,7 +442,7 @@ KivioShapeData::KivioShapeType KivioShapeData::shapeTypeFromString( const TQStri
void KivioShapeData::setShapeType( KivioShapeType st )
{
- m_shapeType = st;
+ m_tqshapeType = st;
// If it is a text box, make sure we have text data
if( st == kstTextBox )
@@ -27,7 +27,7 @@
#include <kdebug.h>
/*
- * Struct for holding information about a shape type
+ * Struct for holding information about a tqshape type
*/
struct KivioShapeTypeInfo
@@ -36,10 +36,10 @@ struct KivioShapeTypeInfo
};
/*
- * Array of shape info used for loading/saving.
+ * Array of tqshape info used for loading/saving.
*/
static const int numShapeInfo = 12;
@@ -420,21 +420,21 @@ TQDomElement KivioShapeData::saveXML( TQDomDocument &doc )
// The BGFillStyle
e.appendChild( m_pFillStyle->saveXML( doc ) );
- // Shape type & name are stored in the shape node
- //XmlWriteInt( e, "shapeType", m_shapeType );
+ // Shape type & name are stored in the tqshape node
+ //XmlWriteInt( e, "tqshapeType", m_tqshapeType );
//XmlWriteString( e, "name", m_name );
return e;